@@ -23,8 +23,9 @@ cliques = {
 class Pyautoqstvm:
     logger: Logger
 
-    def __init__(self, logger: Logger):
-        self.logger = logger
+    def __init__(self, logger: Logger = None, pasta_imagens: str = "mapeamento"):
+        self.logger = logger or Logger.get_logger('logs/rpa.log')
+        self.pasta_imagens = pasta_imagens or self.pasta_imagens
 
     def _raise_or_print(self, msg, raise_errors, verbose=True):
         if raise_errors:
@@ -42,7 +43,7 @@ class Pyautoqstvm:
         raise_errors: bool = True,
         region: tuple[int, int, int, int] = None,
         verbose: bool = True,
-        pasta_imagens: str = "mapeamento",
+        pasta_imagens: str = None,
         extensao_imagem: str = "png",
     ):
         """Aguarda uma imagem surgir na tela e captura sua posição usando pyautogui
@@ -54,14 +55,14 @@ class Pyautoqstvm:
             raise_errors (bool, optional): se True, lança erro quando não encontra a imagem, se não retorna um booleano. Defaults to True.
             region (tuple[int, int, int, int], optional): região específica da tela na qual procurar a imagem. Defaults to None.
             verbose (bool, optional): se deve ou não logar informações usando o logger da biblioteca. Defaults to True.
-            pasta_imagens (str, optional): pasta na qual as imagens de mapeamento são salvas, relativa à raiz. Defaults to "mapeamento".
+            pasta_imagens (str, optional): pasta na qual as imagens de mapeamento são salvas, relativa à raiz. Sobrepõe o valor passado no construtor, se tiver passado. Defaults to "mapeamento".
             extensao_imagem (str, optional): extensão da imagem, sem o ponto. Defaults to 'png'.
 
         Returns:
             bool: se raise_errors for False e não achar a imagem
             Box: se encontrar a imagem, retorna o objeto Box do pyautogui
         """
-        caminho_imagem = os.path.join(pasta_imagens, f"{imagem}.{extensao_imagem}")
+        caminho_imagem = os.path.join(pasta_imagens or self.pasta_imagens, f"{imagem}.{extensao_imagem}")
 
         start_time = time.time()
         found_location = None
@@ -154,7 +155,7 @@ class Pyautoqstvm:
         raise_errors: bool = True,
         region: tuple[int, int, int, int] = None,
         verbose: bool = True,
-        pasta_imagens: str = "mapeamento",
+        pasta_imagens: str = None,
         extensao_imagem: str = "png",
     ) -> bool:
         """
@@ -174,7 +175,7 @@ class Pyautoqstvm:
             raise_errors (bool, optional): se True, lança erro quando não encontra a imagem, se não retorna um booleano. Defaults to True.
             region (tuple[int, int, int, int], optional): região específica da tela na qual procurar a imagem. Defaults to None.
             verbose (bool, optional): se deve ou não logar informações usando o logger da biblioteca. Defaults to True.
-            pasta_imagens (str, optional): pasta na qual as imagens de mapeamento são salvas, relativa à raiz. Defaults to "mapeamento".
+            pasta_imagens (str, optional): pasta na qual as imagens de mapeamento são salvas, relativa à raiz. Sobrepõe o valor passado no construtor, se tiver passado. Defaults to "mapeamento".
             extensao_imagem (str, optional): extensão da imagem, sem o ponto. Defaults to 'png'.
 
         Returns:
@@ -211,7 +212,7 @@ class Pyautoqstvm:
                     if clique == "nada"
                     else f"Clique {clique} realizado"
                 )
-                self.logger.info(f"{msg} nas coordenadas ({x_click}, {y_click}).")
+                self.logger.info(f"{msg} na imagem '{imagem}' ({x_click}, {y_click})")
             return found_location
         except Exception as e:
             msg = f"Erro ao tentar clicar na imagem '{imagem}': {e}"
@@ -258,6 +259,8 @@ class Pyautoqstvm:
         on_error: Callable | None = None,
         confidence: float = 0.9,
         region: tuple[int, int, int, int] = None,
+        pasta_imagens: str = None,
+        extensao_imagem: str = "png"
     ):
         """Espera por uma imagem aparecer na tela, podendo realizar callbacks caso a imagem exista ou não
 
@@ -274,7 +277,7 @@ class Pyautoqstvm:
                                 Valores mais altos são mais estritos. (Padrão: 0.9)
             region (tuple[int, int, int, int], optional): região específica da tela na qual procurar a imagem. Defaults to None.
             verbose (bool, optional): se deve ou não logar informações usando o logger da biblioteca. Defaults to True.
-            pasta_imagens (str, optional): pasta na qual as imagens de mapeamento são salvas, relativa à raiz. Defaults to "mapeamento".
+            pasta_imagens (str, optional): pasta na qual as imagens de mapeamento são salvas, relativa à raiz. Sobrepõe o valor passado no construtor, se tiver passado. Defaults to "mapeamento".
             extensao_imagem (str, optional): extensão da imagem, sem o ponto. Defaults to 'png'.
             msg_erro (str, optional): mensagem de erro lançada caso a validação falhe. Defaults to "Erro de validação de imagem".
             deve_existir (bool, optional): se a imagem deve ser encontrada ou não. Se for False, a existência da imagem se torna um erro. Defaults to True.
@@ -292,6 +295,8 @@ class Pyautoqstvm:
                 verbose=False,
                 confidence=confidence,
                 region=region,
+                pasta_imagens=pasta_imagens,
+                extensao_imagem=extensao_imagem
             )
             if clique == "nada"
             else self.espera_imagem_e_clica(
@@ -304,6 +309,8 @@ class Pyautoqstvm:
                 verbose=False,
                 confidence=confidence,
                 region=region,
+                pasta_imagens=pasta_imagens,
+                extensao_imagem=extensao_imagem
             )
         )
         erro = existe if not deve_existir else not existe
@@ -473,3 +480,11 @@ class Pyautoqstvm:
         except Exception as e:
             self.logger.info(f"Ocorreu um erro inesperado: {e}")
             return False
+
+def encerrar_task(task: str):
+    """Encerra uma task do sistema usando taskkill
+
+    Args:
+        task (str): nome da task usada no taskkill
+    """
+    os.system(f"taskkill /f /im {task} 2>nul")
\ No newline at end of file
